@@ -154,28 +154,30 @@ plot.bootdist <- function(x, main="Bootstrapped values of parameters", enhance=F
     trueval=NULL, rampcol=NULL, nbgrid = 100, nbcol = 100, ...){
     if (!inherits(x, "bootdist"))
         stop("Use only with 'bootdist' objects")
-    if (dim(x$estim)[2]==1) {
-        stripchart(x$estim, method="jitter", main=main, 
-            xlab="Bootstrapped values of the parameter", ...)
+  if (dim(x$estim)[2]==1) 
+  {
+    stripchart(x$estim, method="jitter", main=main, 
+               xlab="Bootstrapped values of the parameter", ...)
+  }
+  else 
+  {
+    if(!is.logical(enhance))
+      stop("wrong argument enhance for plot.bootdist.")
+    if (!enhance)
+    {
+      if(is.null(trueval)) #no true value supplied
+        pairs(data.matrix(x$estim), main=main, ...)
+      else #some true value supplied
+        pairs4boot(x$estim, main=main, trueval=trueval, enhance=FALSE, ...)
     }
-    else {
-      if(!is.logical(enhance))
-        stop("wrong argument enhance for plot.bootdist.")
-      if (!enhance)
-      {
-        if (dim(x$estim)[2]==2)
-          plot(data.matrix(x$estim), main=main, ...)
-        else
-          pairs(data.matrix(x$estim), main=main, ...)
-      }
-      else 
-      {
-        if(is.null(rampcol))
-          rampcol <- c("green", "yellow", "orange", "red")
-        pairs4boot(x$estim, main=main, trueval=trueval, col4ramp = rampcol, 
-                   nbgrid = nbgrid, nbcol = nbcol, ...)
-      }
+    else 
+    {
+      if(is.null(rampcol))
+        rampcol <- c("green", "yellow", "orange", "red")
+      pairs4boot(x$estim, main=main, trueval=trueval, col4ramp = rampcol, 
+                 nbgrid = nbgrid, nbcol = nbcol, ...)
     }
+  }
 }
 
 summary.bootdist <- function(object, ...){
