@@ -22,7 +22,8 @@
 ###         R functions
 ### 
 
-fitdistcens <- function (censdata, distr, start=NULL, fix.arg=NULL, ...) 
+fitdistcens <- function (censdata, distr, start=NULL, fix.arg=NULL, 
+                         keepdata = TRUE, keepdata.nb=100, ...) 
 {
     if (missing(censdata) ||
         !(is.vector(censdata$left) & is.vector(censdata$right) & length(censdata[, 1])>1))
@@ -40,10 +41,12 @@ fitdistcens <- function (censdata, distr, start=NULL, fix.arg=NULL, ...)
     pdistname <- paste("p", distname, sep="")
     if (!exists(pdistname, mode="function"))
         stop(paste("The ", pdistname, " function must be defined"))
-        
-    dots <- list(...)
-    if (length(dots)==0) dots=NULL
+    if(!is.logical(keepdata) || !is.numeric(keepdata.nb) || keepdata.nb < 3)
+      stop("wrong arguments 'keepdata' and 'keepdata.nb'.")
     
+    my3dots <- list(...)    
+    if (length(my3dots) == 0) 
+      my3dots <- NULL
         
     # MLE fit with mledist 
     mle <- mledist(censdata, distname, start, fix.arg, ...)
@@ -75,9 +78,30 @@ fitdistcens <- function (censdata, distr, start=NULL, fix.arg=NULL, ...)
     aic <- -2*loglik+2*npar
     bic <- -2*loglik+log(n)*npar
          
-    return(structure(list(estimate = estimate, sd = sd, cor = correl, vcov = varcovar,
-        loglik = loglik, aic=aic, bic=bic, censdata=censdata, distname=distname,
-        fix.arg=as.list(fix.arg), dots=dots), class = "fitdistcens"))
+    fix.arg <- mle$fix.arg
+    fix.arg.fun <- mle$fix.arg.fun
+    weights <- mle$weights
+    if(keepdata)
+    {
+      reslist <- list(estimate = estimate, sd = sd, cor = correl, vcov = varcovar,
+                    loglik = loglik, aic=aic, bic=bic, censdata=censdata, distname=distname,
+                    fix.arg=as.list(fix.arg), fix.arg.fun = fix.arg.fun, dots=my3dots, 
+                    weights = weights)
+    }else
+    {
+      n2keep <- min(keepdata.nb, n)-4
+      imin <- unique(apply(censdata, 2, which.min))
+      imax <- unique(apply(censdata, 2, which.max))
+      subdata <- censdata[sample((1:n)[-c(imin, imax)], size=n2keep, replace=FALSE), ]
+      subdata <- rbind.data.frame(subdata, censdata[c(imin, imax), ])
+      
+      reslist <- list(estimate = estimate, sd = sd, cor = correl, vcov = varcovar,
+                      loglik = loglik, aic=aic, bic=bic, censdata=subdata, distname=distname,
+                      fix.arg=as.list(fix.arg), fix.arg.fun = fix.arg.fun, dots=my3dots,
+                      weights = weights)
+    }
+      
+    return(structure(reslist, class = "fitdistcens"))
         
 }
 
@@ -86,18 +110,30 @@ print.fitdistcens <- function(x, ...){
         stop("Use only with 'fitdistcens' objects")
     cat("Fitting of the distribution '", x$distname, "' on censored data by maximum likelihood \n")
     cat("Parameters:\n")
-#    op <- options()
-#   options(digits=3)
-    print(data.frame("estimate" = x$estimate), ...)
-#   options(op)
+    print(cbind.data.frame("estimate" = x$estimate), ...)
+
+    if(!is.null(x$fix.arg))
+    {
+      if(is.null(x$fix.arg.fun))
+      {
+        cat("Fixed parameters:\n")
+      }else
+      {
+        cat("Fixed parameters (computed by a user-supplied function):\n")
+      }
+      print(cbind.data.frame("value" = unlist(x$fix.arg)), ...)
+    }
 
 }
 
 plot.fitdistcens <- function(x, ...){
     if (!inherits(x, "fitdistcens"))
         stop("Use only with 'fitdistcens' objects")
-    plotdistcens(censdata=x$censdata, distr=x$distname, 
+    if(!is.null(x$weights))
+      stop("The plot of the fit is not yet available when using weights")
+  plotdistcens(censdata=x$censdata, distr=x$distname, 
     para=c(as.list(x$estimate), as.list(x$fix.arg)), ...)
+    
 }
 
 summary.fitdistcens <- function(object, ...){
@@ -116,10 +152,23 @@ print.summary.fitdistcens <- function(x, ...){
     ddistname <- x$ddistname
     pdistname <- x$pdistname
     
-    cat("FITTING OF THE DISTRIBUTION '", x$distname, 
-    "' BY MAXIMUM LIKELIHOOD ON CENSORED DATA \n")
-    cat("PARAMETERS\n")
-    print(cbind.data.frame("estimate" = x$estimate, "Std. Error" = x$sd))
+    cat("Fitting of the distribution '", x$distname, 
+    "' By maximum likelihood on censored data \n")
+    cat("Parameters\n")
+    print(cbind.data.frame("estimate" = x$estimate, "Std. Error" = x$sd), ...)
+    
+    if(!is.null(x$fix.arg))
+    {
+      if(is.null(x$fix.arg.fun))
+      {
+        cat("Fixed parameters:\n")
+      }else
+      {
+        cat("Fixed parameters (computed by a user-supplied function):\n")
+      }
+      print(cbind.data.frame("value" = unlist(x$fix.arg)), ...)
+    }
+    
     cat("Loglikelihood: ", x$loglik, "  ")
     cat("AIC: ", x$aic, "  ")
     cat("BIC: ", x$bic, "\n")
